@@ -14,11 +14,17 @@
 extern crate core;
 
 #[cfg(feature = "alloc")]
+#[macro_use]
 extern crate alloc;
 
 #[macro_use]
 extern crate tracing;
 
+#[cfg(not(feature = "std"))]
+pub use ockam_executor::{interrupt, tokio};
+#[cfg(feature = "std")]
+pub use tokio;
+
 mod address_record;
 mod context;
 mod error;
@@ -39,7 +45,9 @@ pub use messages::*;
 
 pub use node::{start_node, NullWorker};
 
+#[cfg(feature = "std")]
 use core::future::Future;
+#[cfg(feature = "std")]
 use tokio::{runtime::Runtime, task};
 
 /// Execute a future without blocking the executor
@@ -52,6 +60,7 @@ use tokio::{runtime::Runtime, task};
 /// as an implementation utility for other ockam utilities that use
 /// tokio.
 #[doc(hidden)]
+#[cfg(feature = "std")]
 pub fn block_future<'r, F>(rt: &'r Runtime, f: F) -> <F as Future>::Output
 where
     F: Future + Send,
@@ -64,6 +73,7 @@ where
 }
 
 #[doc(hidden)]
+#[cfg(feature = "std")]
 pub fn spawn<F: 'static>(f: F)
 where
     F: Future + Send,
@@ -71,3 +81,6 @@ where
 {
     task::spawn(f);
 }
+
+#[cfg(not(feature = "std"))]
+pub use crate::tokio::runtime::{block_future, spawn};
